@@ -2,20 +2,14 @@
 import asyncio
 import sys
 
-from outleap import (
-    LEAPClient,
-    LEAPProtocol,
-    LLViewerControlWrapper,
-    connect_stdin_stdout,
-)
+from outleap import LEAPClient, LLViewerControlAPI
 
 
 async def amain():
     # Create a client speaking LEAP over stdin/stdout and connect it
-    reader, writer = await connect_stdin_stdout()
-    async with LEAPClient(LEAPProtocol(reader, writer)) as client:
+    async with await LEAPClient.create_stdio_client() as client:
         # Use our typed wrapper around the LLViewerControl LEAP API
-        viewer_control_api = LLViewerControlWrapper(client)
+        viewer_control_api = LLViewerControlAPI(client)
         # Ask for a config value and print it in the viewer logs
         print(await viewer_control_api.get("Global", "StatsPilotFile"), file=sys.stderr)
 
@@ -25,4 +19,5 @@ def main():
     loop.run_until_complete(amain())
 
 
-main()
+if __name__ == "__main__":
+    main()
